abacusai.pretrained_use_case — AbacusAI documentation

# `abacusai.pretrained_use_case`

## Module Contents

### Classes

`PretrainedUseCase` | Pretrained use case. Used by Abacus.AI internally.

class abacusai.pretrained_use_case.PretrainedUseCase(client, useCase=None, displayName=None, description=None, predictionApi=None, predictionUiDisplayType=None, imgSrc=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Pretrained use case. Used by Abacus.AI internally.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - useCase (str) – Name of the use case, which is the key for the use case in the system.

    - displayName (str) – The name to show to external users.

    - description (str) – A detailed description of the use case.

    - predictionApi (str) – Which prediction api should be used for this use case.

    - predictionUiDisplayType (str) – The component type to show this use case’s prediction dashboard.

    - imgSrc (str) – The source of the image for this use case.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict